bayespy.inference.vmp.nodes.gaussian.GaussianMoments.compute_dims_from_values
=============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianMoments.compute_dims_from_values